@@ -1,9 +1,9 @@
-from patent_client.util.xml import Schema
+from patent_client.uspto.fulltext.schema.base import RegexSchema
+from patent_client.uspto.fulltext.schema.base import Schema
+from patent_client.uspto.fulltext.schema.images import ImageSchema
+from patent_client.uspto.fulltext.schema.publication import PublicationSchema
 from yankee.xml import fields as f
-from yankee.xml import RegexSchema
 
-from ..schema.image_schema import ImageSchema
-from ..schema.new_schema import PublicationSchema
 from .model import Patent
 from .model import PatentImage
 
