@@ -1,9 +1,9 @@
-from yankee.xml import fields as f
-from yankee.xml import RegexSchema
-from yankee.xml import Schema
+from patent_client.util.xml import fields as f
+from patent_client.util.xml import RegexSchema
+from patent_client.util.xml import Schema
 
-from ..schema.image_schema import ImageSchema
-from ..schema.new_schema import PublicationSchema
+from ..schema.images import ImageSchema
+from ..schema.publication import PublicationSchema
 from .model import PublishedApplication
 from .model import PublishedApplicationImage
 
